ImgPy
=====

Image processing library for Python with animated GIFs support - proxy wrapper
around `Pillow <https://github.com/python-pillow/Pillow/>`_ library with simple
usable interface and access to each frame.

|pypi| |travisci|

.. |pypi| image:: https://badge.fury.io/py/imgpy.svg
    :target: https://badge.fury.io/py/imgpy
    :alt: pypi version
.. |travisci| image:: https://travis-ci.org/embali/imgpy.svg?branch=master
    :target: https://travis-ci.org/embali/imgpy
    :alt: travis ci build status

Features
--------

Info (attributes):

* format
* width
* height
* mode
* mode_desc
* n_frames
* animated
* frames

Methods:

* `convert <https://pillow.readthedocs.io/en/4.1.x/reference/Image.html#PIL.Image.Image.convert>`_
* `crop <https://pillow.readthedocs.io/en/4.1.x/reference/Image.html#PIL.Image.Image.crop>`_
* `filter <https://pillow.readthedocs.io/en/4.1.x/reference/Image.html#PIL.Image.Image.filter>`_
* `paste <https://pillow.readthedocs.io/en/4.1.x/reference/Image.html#PIL.Image.Image.paste>`_
* `resize <https://pillow.readthedocs.io/en/4.1.x/reference/Image.html#PIL.Image.Image.resize>`_
* `rotate <https://pillow.readthedocs.io/en/4.1.x/reference/Image.html#PIL.Image.Image.rotate>`_
* `thumbnail <https://pillow.readthedocs.io/en/4.1.x/reference/Image.html#PIL.Image.Image.thumbnail>`_
* `transform <https://pillow.readthedocs.io/en/4.1.x/reference/Image.html#PIL.Image.Image.transform>`_
* `transpose <https://pillow.readthedocs.io/en/4.1.x/reference/Image.html#PIL.Image.Image.transpose>`_
* save
* close

Requirements
------------

* Python 3.5+
* Pillow 4.1.1+

Setup
-----

.. code-block:: bash
    
    python-3.6 -m venv .env
    source .env/bin/activate
    pip install imgpy

Usage
-----

.. code-block:: python

    from imgpy import Img


    # Create thumbnail image
    with Img(fp='test.gif') as im:
        im.thumbnail(size=(100, 100))
        im.save(fp='thumb.gif')

Tests
-----

Run tests: py.test
